[cairo-commit] libpixman/src ic.c, 1.22, 1.23 icblt.c, 1.7, 1.8 icbltone.c, 1.8, 1.9 icint.h, 1.29, 1.30 icpixels.c, 1.7, 1.8 icrop.h, 1.9, 1.10 icstipple.c, 1.6, 1.7 icutil.c, 1.8, 1.9 pixman-xserver-compat.h, 1.3, 1.4 pixman.h, 1.20, 1.21

Jeff Muizelaar commit at pdx.freedesktop.org
Fri Jun 24 18:21:19 PDT 2005


Committed by: jrmuizel

Update of /cvs/cairo/libpixman/src
In directory gabe:/tmp/cvs-serv24495/src

Modified Files:
	ic.c icblt.c icbltone.c icint.h icpixels.c icrop.h icstipple.c 
	icutil.c pixman-xserver-compat.h pixman.h 
Log Message:
2005-06-24  Jeff Muizelaar  <jeff at infidigm.net>

	* src/ic.c: (pixman_compositeSrcAdd_1000x1000),
	(pixman_compositeSolidMask_nx1xn):
	* src/icblt.c: (IcBlt), (IcBlt24Line), (IcBltOdd), (IcSetBltOdd),
	(IcBltStip):
	* src/icbltone.c: (IcBltOne), (IcBltOne24):
	* src/icint.h:
	* src/icpixels.c: (IcPixelsCreate):
	* src/icrop.h:
	* src/icstipple.c: (IcTransparentSpan):
	* src/icutil.c: (IcReplicatePixel):
	* src/pixman-xserver-compat.h:
	s/IC_/FB_/g
	
	* src/pixman.h:
	dd #define FB_BITS IC_BITS so that FB_BITS get defined early enough


Index: ic.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/ic.c,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -d -r1.22 -r1.23
--- ic.c	24 Jun 2005 02:35:45 -0000	1.22
+++ ic.c	25 Jun 2005 01:21:16 -0000	1.23
@@ -789,7 +789,7 @@
 	   height,
 
 	   GXor,
-	   IC_ALLONES,
+	   FB_ALLONES,
 	   srcBpp,
 
 	   0,
@@ -856,7 +856,7 @@
 
 	      0x0,
 	      src,
-	      IC_ALLONES,
+	      FB_ALLONES,
 	      0x0);
 }
 

Index: icint.h
===================================================================
RCS file: /cvs/cairo/libpixman/src/icint.h,v
retrieving revision 1.29
retrieving revision 1.30
diff -u -d -r1.29 -r1.30
--- icint.h	24 Jun 2005 02:30:20 -0000	1.29
+++ icint.h	25 Jun 2005 01:21:16 -0000	1.30
@@ -106,14 +106,14 @@
    drop quite a bit of it. Once the real ic code starts to come
    together I can probably figure out what is not needed here. */
 
-#define IC_UNIT	    (1 << IC_SHIFT)
-#define IC_HALFUNIT (1 << (IC_SHIFT-1))
-#define IC_MASK	    (IC_UNIT - 1)
-#define IC_ALLONES  ((pixman_bits_t) -1)
+#define FB_UNIT	    (1 << FB_SHIFT)
+#define FB_HALFUNIT (1 << (FB_SHIFT-1))
+#define FB_MASK	    (FB_UNIT - 1)
+#define FB_ALLONES  ((pixman_bits_t) -1)
     
 /* whether to bother to include 24bpp support */
 #ifndef ICNO24BIT
-#define IC_24BIT
+#define FB_24BIT
 #endif
 
 /*
@@ -121,36 +121,36 @@
  * windows with 32bpp image format for application compatibility
  */
 
-#ifdef IC_24BIT
+#ifdef FB_24BIT
 #ifndef ICNO24_32
-#define IC_24_32BIT
+#define FB_24_32BIT
 #endif
 #endif
 
-#define IC_STIP_SHIFT	LOG2_BITMAP_PAD
-#define IC_STIP_UNIT	(1 << IC_STIP_SHIFT)
-#define IC_STIP_MASK	(IC_STIP_UNIT - 1)
-#define IC_STIP_ALLONES	((IcStip) -1)
+#define FB_STIP_SHIFT	LOG2_BITMAP_PAD
+#define FB_STIP_UNIT	(1 << FB_STIP_SHIFT)
+#define FB_STIP_MASK	(FB_STIP_UNIT - 1)
+#define FB_STIP_ALLONES	((IcStip) -1)
     
-#define IC_STIP_ODDSTRIDE(s)	(((s) & (IC_MASK >> IC_STIP_SHIFT)) != 0)
-#define IC_STIP_ODDPTR(p)	((((long) (p)) & (IC_MASK >> 3)) != 0)
+#define FB_STIP_ODDSTRIDE(s)	(((s) & (FB_MASK >> FB_STIP_SHIFT)) != 0)
+#define FB_STIP_ODDPTR(p)	((((long) (p)) & (FB_MASK >> 3)) != 0)
     
-#define IcStipStrideToBitsStride(s) (((s) >> (IC_SHIFT - IC_STIP_SHIFT)))
-#define IcBitsStrideToStipStride(s) (((s) << (IC_SHIFT - IC_STIP_SHIFT)))
+#define IcStipStrideToBitsStride(s) (((s) >> (FB_SHIFT - FB_STIP_SHIFT)))
+#define IcBitsStrideToStipStride(s) (((s) << (FB_SHIFT - FB_STIP_SHIFT)))
     
-#define IcFullMask(n)   ((n) == IC_UNIT ? IC_ALLONES : ((((pixman_bits_t) 1) << n) - 1))
+#define IcFullMask(n)   ((n) == FB_UNIT ? FB_ALLONES : ((((pixman_bits_t) 1) << n) - 1))
 
 
 typedef uint32_t	    IcStip;
 typedef int		    IcStride;
 
 
-#ifdef IC_DEBUG
+#ifdef FB_DEBUG
 extern void IcValidateDrawable(DrawablePtr d);
 extern void IcInitializeDrawable(DrawablePtr d);
 extern void IcSetBits (IcStip *bits, int stride, IcStip data);
-#define IC_HEAD_BITS   (IcStip) (0xbaadf00d)
-#define IC_TAIL_BITS   (IcStip) (0xbaddf0ad)
+#define FB_HEAD_BITS   (IcStip) (0xbaadf00d)
+#define FB_TAIL_BITS   (IcStip) (0xbaddf0ad)
 #else
 #define IcValidateDrawable(d)
 #define fdInitializeDrawable(d)
@@ -166,8 +166,8 @@
 #else
 #define IcScrLeft(x,n)	((x) << (n))
 #define IcScrRight(x,n)	((x) >> (n))
-/* #define IcLeftBits(x,n)	((x) >> (IC_UNIT - (n))) */
-#define IcLeftStipBits(x,n) ((x) >> (IC_STIP_UNIT - (n)))
+/* #define IcLeftBits(x,n)	((x) >> (FB_UNIT - (n))) */
+#define IcLeftStipBits(x,n) ((x) >> (FB_STIP_UNIT - (n)))
 #define IcStipMoveLsb(x,s,n)	(x)
 #define IcPatternOffsetBits	(sizeof (pixman_bits_t) - 1)
 #endif
@@ -175,27 +175,27 @@
 #define IcStipLeft(x,n)	IcScrLeft(x,n)
 #define IcStipRight(x,n) IcScrRight(x,n)
 
-#define IcRotLeft(x,n)	IcScrLeft(x,n) | (n ? IcScrRight(x,IC_UNIT-n) : 0)
-#define IcRotRight(x,n)	IcScrRight(x,n) | (n ? IcScrLeft(x,IC_UNIT-n) : 0)
+#define IcRotLeft(x,n)	IcScrLeft(x,n) | (n ? IcScrRight(x,FB_UNIT-n) : 0)
+#define IcRotRight(x,n)	IcScrRight(x,n) | (n ? IcScrLeft(x,FB_UNIT-n) : 0)
 
-#define IcRotStipLeft(x,n)  IcStipLeft(x,n) | (n ? IcStipRight(x,IC_STIP_UNIT-n) : 0)
-#define IcRotStipRight(x,n)  IcStipRight(x,n) | (n ? IcStipLeft(x,IC_STIP_UNIT-n) : 0)
+#define IcRotStipLeft(x,n)  IcStipLeft(x,n) | (n ? IcStipRight(x,FB_STIP_UNIT-n) : 0)
+#define IcRotStipRight(x,n)  IcStipRight(x,n) | (n ? IcStipLeft(x,FB_STIP_UNIT-n) : 0)
 
-#define IcLeftMask(x)	    ( ((x) & IC_MASK) ? \
-			     IcScrRight(IC_ALLONES,(x) & IC_MASK) : 0)
-#define IcRightMask(x)	    ( ((IC_UNIT - (x)) & IC_MASK) ? \
-			     IcScrLeft(IC_ALLONES,(IC_UNIT - (x)) & IC_MASK) : 0)
+#define IcLeftMask(x)	    ( ((x) & FB_MASK) ? \
+			     IcScrRight(FB_ALLONES,(x) & FB_MASK) : 0)
+#define IcRightMask(x)	    ( ((FB_UNIT - (x)) & FB_MASK) ? \
+			     IcScrLeft(FB_ALLONES,(FB_UNIT - (x)) & FB_MASK) : 0)
 
-#define IcLeftStipMask(x)   ( ((x) & IC_STIP_MASK) ? \
-			     IcStipRight(IC_STIP_ALLONES,(x) & IC_STIP_MASK) : 0)
-#define IcRightStipMask(x)  ( ((IC_STIP_UNIT - (x)) & IC_STIP_MASK) ? \
-			     IcScrLeft(IC_STIP_ALLONES,(IC_STIP_UNIT - (x)) & IC_STIP_MASK) : 0)
+#define IcLeftStipMask(x)   ( ((x) & FB_STIP_MASK) ? \
+			     IcStipRight(FB_STIP_ALLONES,(x) & FB_STIP_MASK) : 0)
+#define IcRightStipMask(x)  ( ((FB_STIP_UNIT - (x)) & FB_STIP_MASK) ? \
+			     IcScrLeft(FB_STIP_ALLONES,(FB_STIP_UNIT - (x)) & FB_STIP_MASK) : 0)
 
-#define IcBitsMask(x,w)	(IcScrRight(IC_ALLONES,(x) & IC_MASK) & \
-			 IcScrLeft(IC_ALLONES,(IC_UNIT - ((x) + (w))) & IC_MASK))
+#define IcBitsMask(x,w)	(IcScrRight(FB_ALLONES,(x) & FB_MASK) & \
+			 IcScrLeft(FB_ALLONES,(FB_UNIT - ((x) + (w))) & FB_MASK))
 
-#define IcStipMask(x,w)	(IcStipRight(IC_STIP_ALLONES,(x) & IC_STIP_MASK) & \
-			 IcStipLeft(IC_STIP_ALLONES,(IC_STIP_UNIT - ((x)+(w))) & IC_STIP_MASK))
+#define IcStipMask(x,w)	(IcStipRight(FB_STIP_ALLONES,(x) & FB_STIP_MASK) & \
+			 IcStipLeft(FB_STIP_ALLONES,(FB_STIP_UNIT - ((x)+(w))) & FB_STIP_MASK))
 
 
 #define IcMaskBits(x,w,l,n,r) { \
@@ -203,14 +203,14 @@
     r = IcRightMask((x)+n); \
     l = IcLeftMask(x); \
     if (l) { \
-	n -= IC_UNIT - ((x) & IC_MASK); \
+	n -= FB_UNIT - ((x) & FB_MASK); \
 	if (n < 0) { \
 	    n = 0; \
 	    l &= r; \
 	    r = 0; \
 	} \
     } \
-    n >>= IC_SHIFT; \
+    n >>= FB_SHIFT; \
 }
 
 #ifdef ICNOPIXADDR
@@ -243,7 +243,7 @@
     if (r) { \
 	/* compute right byte length */ \
 	if ((copy) && (((x) + n) & 7) == 0) { \
-	    rb = (((x) + n) & IC_MASK) >> 3; \
+	    rb = (((x) + n) & FB_MASK) >> 3; \
 	} else { \
 	    rb = IcByteMaskInvalid; \
 	} \
@@ -252,18 +252,18 @@
     if (l) { \
 	/* compute left byte length */ \
 	if ((copy) && ((x) & 7) == 0) { \
-	    lb = ((x) & IC_MASK) >> 3; \
+	    lb = ((x) & FB_MASK) >> 3; \
 	} else { \
 	    lb = IcByteMaskInvalid; \
 	} \
 	/* subtract out the portion painted by leftMask */ \
-	n -= IC_UNIT - ((x) & IC_MASK); \
+	n -= FB_UNIT - ((x) & FB_MASK); \
 	if (n < 0) { \
 	    if (lb != IcByteMaskInvalid) { \
 		if (rb == IcByteMaskInvalid) { \
 		    lb = IcByteMaskInvalid; \
 		} else if (rb) { \
-		    lb |= (rb - lb) << (IC_SHIFT - 3); \
+		    lb |= (rb - lb) << (FB_SHIFT - 3); \
 		    rb = 0; \
 		} \
 	    } \
@@ -272,33 +272,33 @@
 	    r = 0; \
 	}\
     } \
-    n >>= IC_SHIFT; \
+    n >>= FB_SHIFT; \
 }
 
-#if IC_SHIFT == 6
+#if FB_SHIFT == 6
 #define IcDoLeftMaskByteRRop6Cases(dst,xor) \
-    case (sizeof (pixman_bits_t) - 7) | (1 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 7) | (1 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (2 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 7) | (2 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (3 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 7) | (3 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (4 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 7) | (4 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (5 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 7) | (5 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 7) | (6 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 7) | (6 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 7,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
@@ -309,21 +309,21 @@
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint32_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (1 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 6) | (1 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (2 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 6) | (2 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (3 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 6) | (3 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (4 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 6) | (4 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 6) | (5 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 6) | (5 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
@@ -332,18 +332,18 @@
 	IcStorePart(dst,sizeof (pixman_bits_t) - 6,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint32_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 5) | (1 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 5) | (1 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 5) | (2 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 5) | (2 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 5) | (3 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 5) | (3 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 5) | (4 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 5) | (4 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
@@ -352,13 +352,13 @@
 	IcStorePart(dst,sizeof (pixman_bits_t) - 5,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint32_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 4) | (1 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 4) | (1 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 4) | (2 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 4) | (2 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 4) | (3 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 4) | (3 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 4,uint16_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
 	break; \
@@ -391,14 +391,14 @@
 #define IcDoLeftMaskByteRRop(dst,lb,l,and,xor) { \
     switch (lb) { \
     IcDoLeftMaskByteRRop6Cases(dst,xor) \
-    case (sizeof (pixman_bits_t) - 3) | (1 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 3) | (1 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 3,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 3) | (2 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 3) | (2 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 3,uint8_t,xor); \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
 	break; \
-    case (sizeof (pixman_bits_t) - 2) | (1 << (IC_SHIFT - 3)): \
+    case (sizeof (pixman_bits_t) - 2) | (1 << (FB_SHIFT - 3)): \
 	IcStorePart(dst,sizeof (pixman_bits_t) - 2,uint8_t,xor); \
 	break; \
     case sizeof (pixman_bits_t) - 3: \
@@ -440,14 +440,14 @@
     r = IcRightStipMask((x)+n); \
     l = IcLeftStipMask(x); \
     if (l) { \
-	n -= IC_STIP_UNIT - ((x) & IC_STIP_MASK); \
+	n -= FB_STIP_UNIT - ((x) & FB_STIP_MASK); \
 	if (n < 0) { \
 	    n = 0; \
 	    l &= r; \
 	    r = 0; \
 	} \
     } \
-    n >>= IC_STIP_SHIFT; \
+    n >>= FB_STIP_SHIFT; \
 }
 
 /*
@@ -479,11 +479,11 @@
 			     ((void)IcLaneCase4((n)&15,a,o), \
 				    IcLaneCase4((n)>>4,a,(o)+4)))
 
-#if IC_SHIFT == 6
+#if FB_SHIFT == 6
 #define IcLaneCase(n,a)   IcLaneCase8(n,(uint8_t *) (a),0)
 #endif
 
-#if IC_SHIFT == 5
+#if FB_SHIFT == 5
 #define IcLaneCase(n,a)   IcLaneCase4(n,(uint8_t *) (a),0)
 #endif
 
@@ -491,14 +491,14 @@
 #define IcRot24(p,b)	    (IcScrRight(p,b) | IcScrLeft(p,24-(b)))
 #define IcRot24Stip(p,b)    (IcStipRight(p,b) | IcStipLeft(p,24-(b)))
 
-/* step a filled pixel value to the next/previous IC_UNIT alignment */
-#define IcNext24Pix(p)	(IcRot24(p,(24-IC_UNIT%24)))
-#define IcPrev24Pix(p)	(IcRot24(p,IC_UNIT%24))
-#define IcNext24Stip(p)	(IcRot24(p,(24-IC_STIP_UNIT%24)))
-#define IcPrev24Stip(p)	(IcRot24(p,IC_STIP_UNIT%24))
+/* step a filled pixel value to the next/previous FB_UNIT alignment */
+#define IcNext24Pix(p)	(IcRot24(p,(24-FB_UNIT%24)))
+#define IcPrev24Pix(p)	(IcRot24(p,FB_UNIT%24))
+#define IcNext24Stip(p)	(IcRot24(p,(24-FB_STIP_UNIT%24)))
+#define IcPrev24Stip(p)	(IcRot24(p,FB_STIP_UNIT%24))
 
 /* step a rotation value to the next/previous rotation value */
-#if IC_UNIT == 64
+#if FB_UNIT == 64
 #define IcNext24Rot(r)        ((r) == 16 ? 0 : (r) + 8)
 #define IcPrev24Rot(r)        ((r) == 0 ? 16 : (r) - 8)
 
@@ -510,7 +510,7 @@
 
 #endif
 
-#if IC_UNIT == 32
+#if FB_UNIT == 32
 #define IcNext24Rot(r)        ((r) == 0 ? 16 : (r) - 8)
 #define IcPrev24Rot(r)        ((r) == 16 ? 0 : (r) + 8)
 
@@ -543,7 +543,7 @@
     (yoff) = icpixels->y; \
 }
 
-#ifdef IC_OLD_SCREEN
+#ifdef FB_OLD_SCREEN
 #define BitsPerPixel(d) (\
     ((1 << PixmapWidthPaddingInfo[d].padBytesLog2) * 8 / \
     (PixmapWidthPaddingInfo[d].padRoundUp+1)))
@@ -551,14 +551,14 @@
 
 #define IcPowerOfTwo(w)	    (((w) & ((w) - 1)) == 0)
 /*
- * Accelerated tiles are power of 2 width <= IC_UNIT
+ * Accelerated tiles are power of 2 width <= FB_UNIT
  */
-#define IcEvenTile(w)	    ((w) <= IC_UNIT && IcPowerOfTwo(w))
+#define IcEvenTile(w)	    ((w) <= FB_UNIT && IcPowerOfTwo(w))
 /*
- * Accelerated stipples are power of 2 width and <= IC_UNIT/dstBpp
+ * Accelerated stipples are power of 2 width and <= FB_UNIT/dstBpp
  * with dstBpp a power of 2 as well
  */
-#define IcEvenStip(w,bpp)   ((w) * (bpp) <= IC_UNIT && IcPowerOfTwo(w) && IcPowerOfTwo(bpp))
+#define IcEvenStip(w,bpp)   ((w) * (bpp) <= FB_UNIT && IcPowerOfTwo(w) && IcPowerOfTwo(bpp))
 
 /*
  * icblt.c
@@ -636,7 +636,7 @@
 	  pixman_bits_t   bgand,
 	  pixman_bits_t   bgxor);
  
-#ifdef IC_24BIT
+#ifdef FB_24BIT
 pixman_private void
 IcBltOne24 (IcStip    *src,
 	  IcStride  srcStride,	    /* IcStip units per scanline */
@@ -793,7 +793,7 @@
 #  define _IcOnes(mask)		__builtin_popcountl((mask) & 0xffffffff)
 # endif
 #else
-# define ICINT_NEED_IC_ONES
+# define ICINT_NEED_FB_ONES
 int
 _IcOnes(unsigned long mask);
 #endif

Index: icpixels.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/icpixels.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -d -r1.7 -r1.8
--- icpixels.c	2 Mar 2005 15:43:33 -0000	1.7
+++ icpixels.c	25 Jun 2005 01:21:16 -0000	1.8
@@ -22,7 +22,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include "icint.h"
+#include "pixman-xserver-compat.h"
 
 static void
 IcPixelsInit (IcPixels *pixels, pixman_bits_t *buf, int width, int height, int depth, int bpp, int stride);
@@ -59,7 +59,7 @@
     unsigned int	base;
 
     bpp = pixman_bits_per_pixel (depth);
-    stride = ((width * bpp + IC_MASK) >> IC_SHIFT) * sizeof (pixman_bits_t);
+    stride = ((width * bpp + FB_MASK) >> FB_SHIFT) * sizeof (pixman_bits_t);
     buf_size = height * stride;
     base = sizeof (IcPixels);
     adjust = 0;

Index: icrop.h
===================================================================
RCS file: /cvs/cairo/libpixman/src/icrop.h,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -d -r1.9 -r1.10
--- icrop.h	2 Mar 2005 15:43:33 -0000	1.9
+++ icrop.h	25 Jun 2005 01:21:16 -0000	1.10
@@ -43,7 +43,7 @@
     _cx2 = _bits->cx2 &  pm; \
 }
 
-#define IcDestInvarientRop(alu,pm)  ((pm) == IC_ALLONES && \
+#define IcDestInvarientRop(alu,pm)  ((pm) == FB_ALLONES && \
 				     (((alu) >> 1 & 5) == ((alu) & 5)))
 
 #define IcDestInvarientMergeRop()   (_ca1 == 0 && _cx1 == 0)
@@ -100,7 +100,7 @@
 /* half of table */
 extern const pixman_bits_t icStipple16Bits[256] pixman_private;
 #define IcStipple16Bits(b) \
-    (icStipple16Bits[(b)&0xff] | icStipple16Bits[(b) >> 8] << IC_HALFUNIT)
+    (icStipple16Bits[(b)&0xff] | icStipple16Bits[(b) >> 8] << FB_HALFUNIT)
 
 pixman_private const pixman_bits_t *
 IcStippleTable(int bits);

Index: icstipple.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/icstipple.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -d -r1.6 -r1.7
--- icstipple.c	24 Jun 2005 02:35:45 -0000	1.6
+++ icstipple.c	25 Jun 2005 01:21:16 -0000	1.7
@@ -42,11 +42,11 @@
 #define LaneCases128(c,a)   LaneCases64(c,a); LaneCases64(c+64,a)
 #define LaneCases256(c,a)   LaneCases128(c,a); LaneCases128(c+128,a)
     
-#if IC_SHIFT == 6
+#if FB_SHIFT == 6
 #define LaneCases(a)	    LaneCases256(0,a)
 #endif
     
-#if IC_SHIFT == 5
+#if FB_SHIFT == 5
 #define LaneCases(a)	    LaneCases16(0,a)
 #endif
 							   
@@ -66,7 +66,7 @@
     s |= ((IcStip) (stip >>  8) & 0x02);
     s |= ((IcStip) (stip >> 16) & 0x04);
     s |= ((IcStip) (stip >> 24) & 0x08);
-#if IC_SHIFT > 5
+#if FB_SHIFT > 5
     s |= ((IcStip) (stip >> 32) & 0x10);
     s |= ((IcStip) (stip >> 40) & 0x20);
     s |= ((IcStip) (stip >> 48) & 0x40);

Index: icutil.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/icutil.c,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -d -r1.8 -r1.9
--- icutil.c	2 Mar 2005 15:43:33 -0000	1.8
+++ icutil.c	25 Jun 2005 01:21:16 -0000	1.9
@@ -22,7 +22,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include "icint.h"
+#include "pixman-xserver-compat.h"
 
 pixman_bits_t
 IcReplicatePixel (Pixel p, int bpp)
@@ -30,7 +30,7 @@
     pixman_bits_t  b = p;
     
     b &= IcFullMask (bpp);
-    while (bpp < IC_UNIT)
+    while (bpp < FB_UNIT)
     {
 	b |= b << bpp;
 	bpp <<= 1;
@@ -39,7 +39,7 @@
 }
 
 #define O 0
-#define I IC_ALLONES
+#define I FB_ALLONES
 
 const IcMergeRopRec IcMergeRopBits[16] = {
     { O,O,O,O },   /* clear	    0x0		0 */
@@ -65,8 +65,8 @@
  * as bitorder == byteorder.  IC doesn't handle the case
  * where these differ
  */
-#define BitsMask(x,w)	((IC_ALLONES << ((x) & IC_MASK)) & \
-			 (IC_ALLONES >> ((IC_UNIT - ((x) + (w))) & IC_MASK)))
+#define BitsMask(x,w)	((FB_ALLONES << ((x) & FB_MASK)) & \
+			 (FB_ALLONES >> ((FB_UNIT - ((x) + (w))) & FB_MASK)))
 
 #define Mask(x,w)	BitsMask((x)*(w),(w))
 
@@ -96,7 +96,7 @@
      SelMask(b,6,w) | \
      SelMask(b,7,w))
 
-#if IC_UNIT == 16
+#if FB_UNIT == 16
 #define icStipple16Bits 0
 #define icStipple8Bits 0
 static const pixman_bits_t icStipple4Bits[16] = {
@@ -110,7 +110,7 @@
     C1(  0,16), C1(  1,16),
 };
 #endif
-#if IC_UNIT == 32
+#if FB_UNIT == 32
 #define icStipple16Bits 0
 static const pixman_bits_t icStipple8Bits[256] = {
     C8(  0,4), C8(  1,4), C8(  2,4), C8(  3,4), C8(  4,4), C8(  5,4),
@@ -168,7 +168,7 @@
     C1(  0,32), C1(  1,32),
 };
 #endif
-#if IC_UNIT == 64
+#if FB_UNIT == 64
 const pixman_bits_t icStipple16Bits[256] = {
     C8(  0,4), C8(  1,4), C8(  2,4), C8(  3,4), C8(  4,4), C8(  5,4),
     C8(  6,4), C8(  7,4), C8(  8,4), C8(  9,4), C8( 10,4), C8( 11,4),

Index: pixman-xserver-compat.h
===================================================================
RCS file: /cvs/cairo/libpixman/src/pixman-xserver-compat.h,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- pixman-xserver-compat.h	3 Mar 2005 21:54:40 -0000	1.3
+++ pixman-xserver-compat.h	25 Jun 2005 01:21:16 -0000	1.4
@@ -68,9 +68,11 @@
 typedef pixman_triangle_t	xTriangle;
 
 #define RENDER 1
+/*
 #define FB_SHIFT IC_SHIFT 
 #define FB_MASK IC_MASK
 #define FB_ALLONES IC_ALLONES
+*/
 #define FbMaskBits IcMaskBits
 
 /* XXX: We changed some function and field names which makes for some

Index: pixman.h
===================================================================
RCS file: /cvs/cairo/libpixman/src/pixman.h,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -d -r1.20 -r1.21
--- pixman.h	18 May 2005 16:25:54 -0000	1.20
+++ pixman.h	25 Jun 2005 01:21:16 -0000	1.21
@@ -272,6 +272,7 @@
 */
 #ifndef IC_SHIFT
 #define IC_SHIFT 5
+#define FB_SHIFT IC_SHIFT
 typedef uint32_t pixman_bits_t;
 #endif
 




More information about the cairo-commit mailing list
Index: icblt.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/icblt.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -d -r1.7 -r1.8
--- icblt.c	24 Jun 2005 02:35:45 -0000	1.7
+++ icblt.c	25 Jun 2005 01:21:16 -0000	1.8
@@ -28,10 +28,10 @@
     if (sx != dx) { \
 	if (sx > dx) { \
 	    ls = sx - dx; \
-	    rs = IC_UNIT - ls; \
+	    rs = FB_UNIT - ls; \
 	} else { \
 	    rs = dx - sx; \
-	    ls = IC_UNIT - rs; \
+	    ls = FB_UNIT - rs; \
 	} \
     } \
 }
@@ -68,7 +68,7 @@
        the memcpy()'s should be pluggable ala mplayer|xine - perhaps we can get
        one of the above to give up their code for us.
      */
-    if((pm==IC_ALLONES) && (alu==GXcopy) && !reverse && (srcX&7)==0 && (dstX&7)==0 && (width&7)==0)
+    if((pm==FB_ALLONES) && (alu==GXcopy) && !reverse && (srcX&7)==0 && (dstX&7)==0 && (width&7)==0)
     {
 		uint8_t *isrc=(uint8_t *)srcLine;
 		uint8_t *idst=(uint8_t *)dstLine;
@@ -88,7 +88,7 @@
 		return;
     }
     
-#ifdef IC_24BIT
+#ifdef FB_24BIT
     if (bpp == 24 && !IcCheck24Pix (pm))
     {
 	IcBlt24 (srcLine, srcStride, srcX, dstLine, dstStride, dstX,
@@ -109,17 +109,17 @@
 		     nmiddle, endmask, endbyte);
     if (reverse)
     {
-	srcLine += ((srcX + width - 1) >> IC_SHIFT) + 1;
-	dstLine += ((dstX + width - 1) >> IC_SHIFT) + 1;
-	srcX = (srcX + width - 1) & IC_MASK;
-	dstX = (dstX + width - 1) & IC_MASK;
+	srcLine += ((srcX + width - 1) >> FB_SHIFT) + 1;
+	dstLine += ((dstX + width - 1) >> FB_SHIFT) + 1;
+	srcX = (srcX + width - 1) & FB_MASK;
+	dstX = (dstX + width - 1) & FB_MASK;
     }
     else
     {
-	srcLine += srcX >> IC_SHIFT;
-	dstLine += dstX >> IC_SHIFT;
-	srcX &= IC_MASK;
-	dstX &= IC_MASK;
+	srcLine += srcX >> FB_SHIFT;
+	dstLine += dstX >> FB_SHIFT;
+	srcX &= FB_MASK;
+	dstX &= FB_MASK;
     }
     if (srcX == dstX)
     {
@@ -218,12 +218,12 @@
 	if (srcX > dstX)
 	{
 	    leftShift = srcX - dstX;
-	    rightShift = IC_UNIT - leftShift;
+	    rightShift = FB_UNIT - leftShift;
 	}
 	else
 	{
 	    rightShift = dstX - srcX;
-	    leftShift = IC_UNIT - rightShift;
+	    leftShift = FB_UNIT - rightShift;
 	}
 	while (height--)
 	{
@@ -333,7 +333,7 @@
     }
 }
 
-#ifdef IC_24BIT
+#ifdef FB_24BIT
 
 #undef DEBUG_BLT24
 #ifdef DEBUG_BLT24
@@ -365,8 +365,8 @@
 {
 #ifdef DEBUG_BLT24
     char    *origDst = (char *) dst;
-    FbBits  *origLine = dst + ((dstX >> IC_SHIFT) - 1);
-    int	    origNlw = ((width + IC_MASK) >> IC_SHIFT) + 3;
+    FbBits  *origLine = dst + ((dstX >> FB_SHIFT) - 1);
+    int	    origNlw = ((width + FB_MASK) >> FB_SHIFT) + 3;
     int	    origX = dstX / 24;
 #endif
     
@@ -380,29 +380,29 @@
     int	    rot;
     IcDeclareMergeRop ();
     
-    IcInitializeMergeRop (alu, IC_ALLONES);
+    IcInitializeMergeRop (alu, FB_ALLONES);
     IcMaskBits(dstX, width, startmask, n, endmask);
 #ifdef DEBUG_BLT24
     ErrorF ("dstX %d width %d reverse %d\n", dstX, width, reverse);
 #endif
     if (reverse)
     {
-	src += ((srcX + width - 1) >> IC_SHIFT) + 1;
-	dst += ((dstX + width - 1) >> IC_SHIFT) + 1;
-	rot = IcFirst24Rot (((dstX + width - 8) & IC_MASK));
+	src += ((srcX + width - 1) >> FB_SHIFT) + 1;
+	dst += ((dstX + width - 1) >> FB_SHIFT) + 1;
+	rot = IcFirst24Rot (((dstX + width - 8) & FB_MASK));
 	rot = IcPrev24Rot(rot);
 #ifdef DEBUG_BLT24
-	ErrorF ("dstX + width - 8: %d rot: %d\n", (dstX + width - 8) & IC_MASK, rot);
+	ErrorF ("dstX + width - 8: %d rot: %d\n", (dstX + width - 8) & FB_MASK, rot);
 #endif
-	srcX = (srcX + width - 1) & IC_MASK;
-	dstX = (dstX + width - 1) & IC_MASK;
+	srcX = (srcX + width - 1) & FB_MASK;
+	dstX = (dstX + width - 1) & FB_MASK;
     }
     else
     {
-	src += srcX >> IC_SHIFT;
-	dst += dstX >> IC_SHIFT;
-	srcX &= IC_MASK;
-	dstX &= IC_MASK;
+	src += srcX >> FB_SHIFT;
+	dst += dstX >> FB_SHIFT;
+	srcX &= FB_MASK;
+	dstX &= FB_MASK;
 	rot = IcFirst24Rot (dstX);
 #ifdef DEBUG_BLT24
 	ErrorF ("dstX: %d rot: %d\n", dstX, rot);
@@ -465,12 +465,12 @@
 	if (srcX > dstX)
 	{
 	    leftShift = srcX - dstX;
-	    rightShift = IC_UNIT - leftShift;
+	    rightShift = FB_UNIT - leftShift;
 	}
 	else
 	{
 	    rightShift = dstX - srcX;
-	    leftShift = IC_UNIT - rightShift;
+	    leftShift = FB_UNIT - rightShift;
 	}
 	
 	bits1 = 0;
@@ -598,12 +598,12 @@
     ErrorF ("\n");
 #endif
 }
-#endif /* IC_24BIT */
+#endif /* FB_24BIT */
 
-#if IC_SHIFT == IC_STIP_SHIFT + 1
+#if FB_SHIFT == FB_STIP_SHIFT + 1
 
 /*
  * Could be generalized to IC_SHIFT > IC_STIP_SHIFT + 1 by
  * creating an ring of values stepped through for each line
  */
 
@@ -653,12 +653,12 @@
     IcInitializeMergeRop (alu, pm);
     destInvarient = IcDestInvarientMergeRop();
 
-    srcLine += srcXEven >> IC_SHIFT;
-    dstLine += dstXEven >> IC_SHIFT;
-    srcXEven &= IC_MASK;
-    dstXEven &= IC_MASK;
-    srcXOdd &= IC_MASK;
-    dstXOdd &= IC_MASK;
+    srcLine += srcXEven >> FB_SHIFT;
+    dstLine += dstXEven >> FB_SHIFT;
+    srcXEven &= FB_MASK;
+    dstXEven &= FB_MASK;
+    srcXOdd &= FB_MASK;
+    dstXOdd &= FB_MASK;
 
     IcMaskBits(dstXEven, width, startmaskEven, nmiddleEven, endmaskEven);
     IcMaskBits(dstXOdd, width, startmaskOdd, nmiddleOdd, endmaskOdd);
@@ -779,7 +779,7 @@
     }
 }
 
-#ifdef IC_24BIT
+#ifdef FB_24BIT
 void
 IcBltOdd24 (FbBits	*srcLine,
 	    IcStride	srcStrideEven,
@@ -828,7 +828,7 @@
 
 #endif
 
-#if IC_STIP_SHIFT != IC_SHIFT
+#if FB_STIP_SHIFT != FB_SHIFT
 void
 IcSetBltOdd (IcStip	*stip,
 	     IcStride	stipStride,
@@ -845,11 +845,11 @@
     /*
      * bytes needed to align source
      */
-    srcAdjust = (((int) stip) & (IC_MASK >> 3));
+    srcAdjust = (((int) stip) & (FB_MASK >> 3));
     /*
      * IcStip units needed to align stride
      */
-    strideAdjust = stipStride & (IC_MASK >> IC_STIP_SHIFT);
+    strideAdjust = stipStride & (FB_MASK >> FB_STIP_SHIFT);
 
     *bits = (FbBits *) ((char *) stip - srcAdjust);
     if (srcAdjust)
@@ -858,7 +858,7 @@
 	*strideOdd = IcStipStrideToBitsStride (stipStride);
 
 	*srcXEven = srcX + (srcAdjust << 3);
-	*srcXOdd = srcX + (srcAdjust << 3) - (strideAdjust << IC_STIP_SHIFT);
+	*srcXOdd = srcX + (srcAdjust << 3) - (strideAdjust << FB_STIP_SHIFT);
     }
     else
     {
@@ -866,7 +866,7 @@
 	*strideOdd = IcStipStrideToBitsStride (stipStride + 1);
 	
 	*srcXEven = srcX;
-	*srcXOdd = srcX + (strideAdjust << IC_STIP_SHIFT);
+	*srcXOdd = srcX + (strideAdjust << FB_STIP_SHIFT);
     }
 }
 #endif
@@ -887,9 +887,9 @@
 	   FbBits   pm,
 	   int	    bpp)
 {
-#if IC_STIP_SHIFT != IC_SHIFT
-    if (IC_STIP_ODDSTRIDE(srcStride) || IC_STIP_ODDPTR(src) ||
-	IC_STIP_ODDSTRIDE(dstStride) || IC_STIP_ODDPTR(dst))
+#if FB_STIP_SHIFT != FB_SHIFT
+    if (FB_STIP_ODDSTRIDE(srcStride) || FB_STIP_ODDPTR(src) ||
+	FB_STIP_ODDSTRIDE(dstStride) || FB_STIP_ODDPTR(dst))
     {
 	IcStride    srcStrideEven, srcStrideOdd;
 	IcStride    dstStrideEven, dstStrideOdd;
@@ -898,10 +898,10 @@
 	FbBits	    *s, *d;
 	int	    sx, dx;
 	
-	src += srcX >> IC_STIP_SHIFT;
-	srcX &= IC_STIP_MASK;
-	dst += dstX >> IC_STIP_SHIFT;
-	dstX &= IC_STIP_MASK;
+	src += srcX >> FB_STIP_SHIFT;
+	srcX &= FB_STIP_MASK;
+	dst += dstX >> FB_STIP_SHIFT;
+	dstX &= FB_STIP_MASK;
 	
 	IcSetBltOdd (src, srcStride, srcX,
 		     &s,
@@ -913,7 +913,7 @@
 		     &dstStrideEven, &dstStrideOdd,
 		     &dstXEven, &dstXOdd);
 		     
-#ifdef IC_24BIT
+#ifdef FB_24BIT
 	if (bpp == 24 && !IcCheck24Pix (pm))
 	{
 	    IcBltOdd24  (s, srcStrideEven, srcStrideOdd,
@@ -598,12 +598,12 @@
 
 /*
- * Could be generalized to IC_SHIFT > IC_STIP_SHIFT + 1 by
+ * Could be generalized to FB_SHIFT > FB_STIP_SHIFT + 1 by
  * creating an ring of values stepped through for each line
  */

Index: icbltone.c
===================================================================
RCS file: /cvs/cairo/libpixman/src/icbltone.c,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -d -r1.8 -r1.9
--- icbltone.c	24 Jun 2005 02:35:45 -0000	1.8
+++ icbltone.c	25 Jun 2005 01:21:16 -0000	1.9
@@ -25,7 +25,7 @@
 #include "pixman-xserver-compat.h"
 
 /*
- *  Example: srcX = 13 dstX = 8	(IC unit 32 dstBpp 8)
+ *  Example: srcX = 13 dstX = 8	(FB unit 32 dstBpp 8)
  *
  *	**** **** **** **** **** **** **** ****
  *			^
@@ -34,7 +34,7 @@
  *  leftShift = 12
  *  rightShift = 20
  *
- *  Example: srcX = 0 dstX = 8 (IC unit 32 dstBpp 8)
+ *  Example: srcX = 0 dstX = 8 (FB unit 32 dstBpp 8)
  *
  *	**** **** **** **** **** **** **** ****
  *	^		
@@ -55,7 +55,7 @@
 	bits = *src++; \
 }
     
-#ifndef ICNOPIXADDR
+#ifndef FBNOPIXADDR
     
 #define LaneCases1(n,a)	    case n: (void)IcLaneCase(n,a); break
 #define LaneCases2(n,a)	    LaneCases1(n,a); LaneCases1(n+1,a)
@@ -67,15 +67,15 @@
 #define LaneCases128(n,a)   LaneCases64(n,a); LaneCases64(n+64,a)
 #define LaneCases256(n,a)   LaneCases128(n,a); LaneCases128(n+128,a)
     
-#if IC_SHIFT == 6
+#if FB_SHIFT == 6
 #define LaneCases(a)	    LaneCases256(0,a)
 #endif
     
-#if IC_SHIFT == 5
+#if FB_SHIFT == 5
 #define LaneCases(a)	    LaneCases16(0,a)
 #endif
 							   
-#if IC_SHIFT == 6
+#if FB_SHIFT == 6
 static uint8_t const Ic8Lane[256] = {
 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
@@ -105,7 +105,7 @@
 };
 #endif
 
-#if IC_SHIFT == 5
+#if FB_SHIFT == 5
 static uint8_t const Ic8Lane[16] = {
     0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15
 };
@@ -167,12 +167,12 @@
     int	    transparent;		/* accelerate 0 nop */
     int		    srcinc;			/* source units consumed */
     int	    endNeedsLoad = 0;	/* need load for endmask */
-#ifndef ICNOPIXADDR
+#ifndef FBNOPIXADDR
     const uint8_t	    *IcLane;
 #endif
     int		    startbyte, endbyte;
 
-#ifdef IC_24BIT
+#ifdef FB_24BIT
     if (dstBpp == 24)
     {
 	IcBltOne24 (src, srcStride, srcX,
@@ -187,27 +187,27 @@
      * Number of destination units in FbBits == number of stipple pixels
      * used each time
      */
-    pixelsPerDst = IC_UNIT / dstBpp;
+    pixelsPerDst = FB_UNIT / dstBpp;
 
     /*
      * Number of source stipple patterns in IcStip 
      */
-    unitsPerSrc = IC_STIP_UNIT / pixelsPerDst;
+    unitsPerSrc = FB_STIP_UNIT / pixelsPerDst;
     
     copy = 0;
     transparent = 0;
     if (bgand == 0 && fgand == 0)
 	copy = 1;
-    else if (bgand == IC_ALLONES && bgxor == 0)
+    else if (bgand == FB_ALLONES && bgxor == 0)
 	transparent = 1;
 
     /*
      * Adjust source and dest to nearest FbBits boundary
      */
-    src += srcX >> IC_STIP_SHIFT;
-    dst += dstX >> IC_SHIFT;
-    srcX &= IC_STIP_MASK;
-    dstX &= IC_MASK;
+    src += srcX >> FB_STIP_SHIFT;
+    dst += dstX >> FB_SHIFT;
+    srcX &= FB_STIP_MASK;
+    dstX &= FB_MASK;
 
     IcMaskBitsBytes(dstX, width, copy, 
 		    startmask, startbyte, nmiddle, endmask, endbyte);
@@ -223,12 +223,12 @@
     if (srcX >= dstS)
     {
 	leftShift = srcX - dstS;
-	rightShift = IC_STIP_UNIT - leftShift;
+	rightShift = FB_STIP_UNIT - leftShift;
     }
     else
     {
 	rightShift = dstS - srcX;
-	leftShift = IC_STIP_UNIT - rightShift;
+	leftShift = FB_STIP_UNIT - rightShift;
     }
     /*
      * Get pointer to stipple mask array for this depth
@@ -236,7 +236,7 @@
     icbits = 0;	/* unused */
     if (pixelsPerDst <= 8)
 	icbits = IcStippleTable(pixelsPerDst);
-#ifndef ICNOPIXADDR
+#ifndef FBNOPIXADDR
     IcLane = 0;
     if (transparent && fgand == 0 && dstBpp >= 8)
 	IcLane = IcLaneTable(dstBpp);
@@ -294,13 +294,13 @@
 	     */
 	    if (startmask)
 	    {
-#if IC_UNIT > 32
+#if FB_UNIT > 32
 		if (pixelsPerDst == 16)
 		    mask = IcStipple16Bits(IcLeftStipBits(bits,16));
 		else
 #endif
 		    mask = icbits[IcLeftStipBits(bits,pixelsPerDst)];
-#ifndef ICNOPIXADDR		
+#ifndef FBNOPIXADDR		
 		if (IcLane)
 		{
 		    IcTransparentSpan (dst, mask & startmask, fgxor, 1);
@@ -328,7 +328,7 @@
 		{
 		    while (n--)
 		    {
-#if IC_UNIT > 32
+#if FB_UNIT > 32
 			if (pixelsPerDst == 16)
 			    mask = IcStipple16Bits(IcLeftStipBits(bits,16));
 			else
@@ -341,7 +341,7 @@
 		}
 		else
 		{
-#ifndef ICNOPIXADDR
+#ifndef FBNOPIXADDR
 		    if (IcLane)
 		    {
 			while (bits && n)
@@ -392,13 +392,13 @@
 	    {
 		LoadBits;
 	    }
-#if IC_UNIT > 32
+#if FB_UNIT > 32
 	    if (pixelsPerDst == 16)
 		mask = IcStipple16Bits(IcLeftStipBits(bits,16));
 	    else
 #endif
 		mask = icbits[IcLeftStipBits(bits,pixelsPerDst)];
-#ifndef ICNOPIXADDR
+#ifndef FBNOPIXADDR
 	    if (IcLane)
 	    {
 		IcTransparentSpan (dst, mask & endmask, fgxor, 1);
@@ -417,7 +417,7 @@
     }
 }
 
-#ifdef IC_24BIT
+#ifdef FB_24BIT
 
 /*
  * Crufty macros to initialize the mask array, most of this
@@ -432,9 +432,9 @@
 
 #define Mask24Neg(x,r)	(Mask24Pos(x,r) < 0 ? -Mask24Pos(x,r) : 0)
 #define Mask24Check(x,r)    (Mask24Pos(x,r) < 0 ? 0 : \
-			     Mask24Pos(x,r) >= IC_UNIT ? 0 : Mask24Pos(x,r))
+			     Mask24Pos(x,r) >= FB_UNIT ? 0 : Mask24Pos(x,r))
 
-#define Mask24(x,r) (Mask24Pos(x,r) < IC_UNIT ? \
+#define Mask24(x,r) (Mask24Pos(x,r) < FB_UNIT ? \
 		     (Mask24Pos(x,r) < 0 ? \
 		      0xffffff >> Mask24Neg (x,r) : \
 		      0xffffff << Mask24Check(x,r)) : 0)
@@ -442,10 +442,10 @@
 #define SelMask24(b,n,r)	((((b) >> n) & 1) * Mask24(n,r))
 
 /*
  * Untested for MSBFirst or IC_UNIT == 32
  */
 
-#if IC_UNIT == 64
+#if FB_UNIT == 64
 #define C4_24(b,r) \
     (SelMask24(b,0,r) | \
      SelMask24(b,1,r) | \
@@ -481,7 +481,7 @@
 
 #endif
 
-#if IC_UNIT == 32
+#if FB_UNIT == 32
 #define C2_24(b,r)  \
     (SelMask24(b,0,r) | \
      SelMask24(b,1,r))
@@ -537,7 +537,7 @@
 	__len = (len) - remain; \
 	stip = IcMergePartStip24Bits(stip, IcLeftStipBits(bits, __len), \
 				     remain, __len); \
-	remain = IC_STIP_UNIT; \
+	remain = FB_STIP_UNIT; \
     } \
     bits = IcStipLeft (bits, __len); \
     remain -= __len; \
@@ -545,7 +545,7 @@
 
 #define IcInitStipBits(offset,len,stip) {\
     bits = IcStipLeft (*src++,offset); \
-    remain = IC_STIP_UNIT - offset; \
+    remain = FB_STIP_UNIT - offset; \
     IcFirstStipBits(len,stip); \
     stip = IcMergeStip24Bits (0, stip, len); \
 }
@@ -594,10 +594,10 @@
     int		rot0, rot;
     int		nDst;
     
-    srcLine += srcX >> IC_STIP_SHIFT;
-    dst += dstX >> IC_SHIFT;
-    srcX &= IC_STIP_MASK;
-    dstX &= IC_MASK;
+    srcLine += srcX >> FB_STIP_SHIFT;
+    dst += dstX >> FB_SHIFT;
+    srcX &= FB_STIP_MASK;
+    dstX &= FB_MASK;
     rot0 = IcFirst24Rot (dstX);
     
     IcMaskBits (dstX, width, leftMask, nlMiddle, rightMask);
@@ -652,7 +652,7 @@
 	}
     }
     /* transparent copy */
-    else if (bgand == IC_ALLONES && bgxor == 0 && fgand == 0)
+    else if (bgand == FB_ALLONES && bgxor == 0 && fgand == 0)
     {
 	while (height--)
 	{
@@ -442,10 +442,10 @@
 
 /*
- * Untested for MSBFirst or IC_UNIT == 32
+ * Untested for MSBFirst or FB_UNIT == 32
  */
 
